@@ -1,5 +1,5 @@
 # This is the official version source.  Bump it before releases.
-__version__="0.1.2"
+__version__="0.1.4"
 
 from .availability import Availability
-from .campsites import Campsite, CampsiteSet
\ No newline at end of file
+from .campsites import Campsite, CampsiteSet, get_campsites
\ No newline at end of file
